@@ -10,6 +10,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
+import csv
+from io import StringIO
 import cannerflow.workspace
 import cannerflow.constants
 import cannerflow.exceptions
@@ -61,26 +64,50 @@ class Client(object):
         return self.workspace.file.list_absolute_path()
     def get_binary(self, absolute_path):
         return self.workspace.file.get_content(absolute_path)
-
+    def put_binary(self, absolute_path, data):
+        return self.workspace.file.put(absolute_path, data)
     # wrappers
     def _get_csv_wrapper(self, absolute_path, encoding='utf-8'):
         return self.workspace.file.get_csv_wrapper(absolute_path, encoding=encoding)
     def _get_json_wrapper(self, absolute_path, encoding='utf-8'):
         return self.workspace.file.get_json_wrapper(absolute_path, encoding=encoding)
+
     def _get_image_wrapper(self, absolute_path):
         return self.workspace.file.get_image_wrapper(absolute_path)
+
     # csv
     def get_csv(self, absolute_path, encoding='utf-8'):
         return self._get_csv_wrapper(absolute_path, encoding).to_list()
+
     def get_pandas_csv(self, absolute_path, encoding='utf-8', *args, **kwargs):
         return self._get_csv_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
 
+    def put_csv(self, absolute_path, data, encoding='utf-8', *args, **kwargs):
+        str_io = StringIO()
+        csv_writer = csv.writer(str_io, *args, **kwargs)
+        csv_writer.writerows(data)
+        value = str_io.getvalue().encode(encoding)
+        return self.put_binary(absolute_path=absolute_path, data=value)
+
+    def put_pandas_csv(self, absolute_path, data, encoding='utf-8'):
+        data = data.to_csv(index=False).encode(encoding)
+        return self.put_binary(absolute_path=absolute_path, data=data)
+
     # json
     def get_json(self, absolute_path, encoding='utf-8'):
         return self._get_json_wrapper(absolute_path, encoding).to_json()
+
     def get_pandas_json(self, absolute_path, encoding='utf-8', *args, **kwargs):
         return self._get_json_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
-    
+
+    def put_json(self, absolute_path, data, encoding='utf-8'):
+        data = json.dumps(data).encode(encoding)
+        return self.put_binary(absolute_path=absolute_path, data=data)
+
+    def put_pandas_json(self, absolute_path, data, encoding='utf-8'):
+        data = data.to_json()
+        self.put_json(self, absolute_path=absolute_path, data=data, encoding=encoding)
+
     # image
     def get_pil_image(self, absolute_path):
         return self._get_image_wrapper(absolute_path).to_pil()
